OneWay

Struct OneWay 

pub struct OneWay<Message> { /* private fields */ }
Worker’s mode that has a communication channel between the worker and its task. In this channel the messages, with type Message, can be send from the worker to the task using the function super::Worker<Mode>::post_message().